==========
PyScaffold
==========


PyScaffold helps you to easily setup a new Python project, it is as easy as::

    putup my_project

This will create a new subdirectory ``my_project`` and serve you a project
setup with git repository, setup.py, document and test folder ready for some
serious coding.

Type ``putup -h`` to learn about more configuration options. PyScaffold assumes
that you have `Git  <http://git-scm.com/>`_ installed and set up on your PC,
meaning at least your name and email configured.
The scaffold of ``my_project`` provides you with a lot of
:ref:`features <features>`. PyScaffold is compatible with Python 2.7, 3.3 and
3.4.


Contents
--------

.. toctree::
   :maxdepth: 2

   Features <features>
   Contributions & Issues <contrib>
   License <license>
   Module Reference <_rst/modules>


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
